NetworkResult<T> class
sealed
Constructors
- NetworkResult.failure(NetworkException exception)
-
factory
- NetworkResult.success(T data)
-
factory
Properties
- dataOrNull → T?
-
no setter
- exceptionOrNull → NetworkException?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
no setter
- isSuccess → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({required R onSuccess(T data), required R onFailure(NetworkException exception)}) → R
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited